@@ -64,6 +64,7 @@ pub struct TreeBuilder<'c> {
     con: &'c AppContext,
     pub matches_max: Option<usize>, // optional hard limit
     trim_root: bool,
+    pub deep: bool,
     report: BuildReport,
 }
 impl<'c> TreeBuilder<'c> {
@@ -109,6 +110,7 @@ impl<'c> TreeBuilder<'c> {
             con,
             trim_root,
             matches_max: None,
+            deep: true,
             report: BuildReport::default(),
         })
     }
@@ -125,14 +127,21 @@ impl<'c> TreeBuilder<'c> {
             self.report.error_count += 1;
             return None;
         }
-        if !self.options.show_hidden && name.as_bytes()[0] == b'.' {
+        let path = e.path();
+        if !self.options.show_hidden
+            && name.as_bytes()[0] == b'.'
+            // if not matches any SpecialHandling::NoHide pattern
+            && !self.con.special_paths
+            .iter()
+            .filter(|sp| sp.handling == SpecialHandling::NoHide)
+            .any(|sp| sp.pattern.matches_path(&path))
+        {
             self.report.hidden_count += 1;
             return None;
         }
         let name = name.to_string_lossy();
         let mut has_match = true;
         let mut score = 10000 - i32::from(depth); // we dope less deep entries
-        let path = e.path();
         let file_type = match e.file_type() {
             Ok(ft) => ft,
             Err(_) => {
@@ -287,6 +296,7 @@ impl<'c> TreeBuilder<'c> {
         let mut next_level_dirs: Vec<BId> = Vec::new();
         self.load_children(self.root_id);
         open_dirs.push_back(self.root_id);
+        let deep = self.deep && !self.options.sort.prevent_deep_display();
         loop {
             if !total_search && (
                 (nb_lines_ok > optimal_size)
@@ -314,8 +324,7 @@ impl<'c> TreeBuilder<'c> {
                 }
             } else {
                 // this depth is finished, we must go deeper
-                if self.options.sort.prevent_deep_display() {
-                    // in sort mode, only one level is displayed
+                if !deep {
                     break;
                 }
                 if next_level_dirs.is_empty() {
